package com.miaxis.app.controller.car;

import com.miaxis.car.domain.UsedCarInfo;
import com.miaxis.car.dto.UsedCarInfoDto;
import com.miaxis.car.service.IUsedCarInfoService;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.domain.entity.UserInfo;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import com.miaxis.common.utils.SecurityUtils;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * 二手车 Controller
 * @author wwl
 * @version 1.0
 * @date 2021/5/27 13:32
 */
@RestController
@RequiredArgsConstructor
@RequestMapping(Constants.STUDENT_PREFIX+"/applet/usedCar")
@Api(tags={"【小程序-二手车】"})
public class AppletUsedCarInfoController extends BaseController {

    private final IUsedCarInfoService usedCarInfoService;

    /**
     * 查询二手车参数列表
     */
    @GetMapping("/dictDataCarList/{parameterTypes}")
    @ApiOperation("查询二手车参数列表")
    public Response dictDataCarList(@ApiParam(name = "parameterTypes",value = "参数类型",required = true)
                                    @PathVariable("parameterTypes") String[] parameterTypes){
        return usedCarInfoService.selectDictDataCarList(parameterTypes);
    }

    /**
     * 查询二手车列表
     */
    @GetMapping("/list")
    @ApiOperation("查询二手车列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<UsedCarInfo> list(@ModelAttribute UsedCarInfo usedCarInfo){
        startPage();
        List<UsedCarInfo> list = usedCarInfoService.selectUsedCarInfoList(usedCarInfo);
        return toResponsePageInfo(list);
    }


    /**
     * 发布二手车
     */
    @PostMapping
    @ApiOperation("发布二手车")
    public Response add(@RequestBody UsedCarInfoDto usedCarInfoDto){
        UserInfo userInfo = SecurityUtils.getLoginUser().getStudent();
        usedCarInfoDto.setUserId(userInfo.getId());
        return usedCarInfoService.saveUsedCarInfo(usedCarInfoDto);
    }


    /**
     * 编辑二手车
     * @param usedCarInfoDto
     * @return
     */
    @PutMapping
    @ApiOperation("编辑二手车")
    public Response edit(@RequestBody UsedCarInfoDto usedCarInfoDto){
        return usedCarInfoService.editUsedCarById(usedCarInfoDto);
    }


    /**
     * 二手商品详细信息
     */
    @GetMapping(value = "/{id}")
    @ApiOperation("二手商品详细信息")
    public Response getInfo(
            @ApiParam(name = "id", value = "首页数据id", required = true)
            @PathVariable("id") Long id
    ){
        return usedCarInfoService.getUsedCarById(id);
    }


    /**
     * 删除二手车(伪删除)
     */
    @Log(title = "删除二手车", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping("/{ids}")
    @ApiOperation("删除二手车")
    public  Response remove(
            @ApiParam(name = "ids", value = "二手车ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return usedCarInfoService.removeUsedCarByIds(ids);
    }


}
