package com.miaxis.app.controller.collection;

import com.miaxis.collection.service.ICollectionInfoService;
import com.miaxis.collection.vo.CollectionCustomerVo;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.domain.entity.UserInfo;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.utils.SecurityUtils;
import io.swagger.annotations.*;
import lombok.RequiredArgsConstructor;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * 【小程序-收藏管理】Controller
 *
 * @author miaxis
 * @date 2021-03-10
 */
@RestController
@RequiredArgsConstructor
@RequestMapping(Constants.STUDENT_PREFIX+"/applet/collection")
@Api(tags = {"【小程序-收藏管理】"})
public class AppletCollectionInfoController extends BaseController {

    private final ICollectionInfoService collectionInfoService;


    /**
     * 查询用户收藏列表
     */
    @GetMapping("/collectionList")
    @ApiOperation("查询用户收藏列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "当前页码", dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize", value = "每页数据量", dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<CollectionCustomerVo> collectionList() {
        startPage();
        //当前用户
        UserInfo userInfo = SecurityUtils.getLoginUser().getStudent();
        List<CollectionCustomerVo> list = collectionInfoService.collectionList(userInfo);
        return toResponsePageInfo(list);
    }


    /**
     * 收藏商家
     */
    @PutMapping(value = "/collectionBusiness/{id}")
    @ApiOperation("收藏商家")
    public Response collectionBusiness(
            @ApiParam(name = "id",value = "商家id",required = true)
            @PathVariable("id") Long id
    ){
        //当前用户
        UserInfo userInfo = SecurityUtils.getLoginUser().getStudent();
        return collectionInfoService.collectionBusiness(userInfo,id);
    }

    /**
     * 取消收藏商家
     */
    @DeleteMapping(value = "/cancelCollection/{ids}")
    @ApiOperation("取消收藏")
    public Response cancelCollection(
            @ApiParam(name = "ids", value = "商家id", required = true)
            @PathVariable Long[] ids
    ){
        //当前用户
        UserInfo userInfo = SecurityUtils.getLoginUser().getStudent();
        return collectionInfoService.removeCollectionByIds(userInfo.getId(),ids);
    }


}
