package com.miaxis.app.controller.fulu;


import com.alibaba.fastjson.JSONObject;
import com.miaxis.common.config.WxpayConfig;
import com.miaxis.common.constant.Constants;
import com.miaxis.common.enums.OrderStatusEnum;
import com.miaxis.common.exception.CustomException;
import com.miaxis.feign.dto.WxSend;
import com.miaxis.feign.service.IWxSendService;
import com.miaxis.wx.domain.WxOrder;
import com.miaxis.wx.dto.FilmWxOrderJsonData;
import com.miaxis.wx.dto.FuluWxOrderJsonData;
import com.miaxis.wx.dto.WxFuluOrderDetailDTO;
import com.miaxis.wx.dto.WxOrderNotifyDTO;
import com.miaxis.wx.service.IRefundRecordService;
import com.miaxis.wx.service.IWxOrderService;
import com.miaxis.wx.service.IWxXcxMessageService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.Data;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.util.Date;

import static com.miaxis.common.utils.OrderCodeFactory.getOrderCode;

@RestController
@RequiredArgsConstructor
@RequestMapping(Constants.OPEN_PREFIX+"/fulu/notify")
@Api(tags = {"【小程序-福禄回调】"})
@Slf4j
public class FuluNotifyController {


    @Autowired
    private WxpayConfig wxpayConfig;


    @Autowired
    private IWxOrderService wxOrderService;

    @Autowired
    private ThreadPoolTaskExecutor threadPoolTaskExecutor;

    @Autowired
    private  IRefundRecordService  refundRecordService;

    @Autowired
    IWxXcxMessageService wxXcxMessageService;

    @Resource
    private IWxSendService wxSendService;



    /**
     * 电影回调接口
     */
    @PostMapping(value = "/fuluOrder")
    @ApiOperation("福禄订单回调")
    public FilmNotifyReturnDTO wxOrderNotify(@RequestBody WxFuluOrderDetailDTO wxFuluOrderDetailDTO) {
        log.info("福禄回调订单:"+wxFuluOrderDetailDTO.getCustomer_order_no()+",入参:"+JSONObject.toJSONString(wxFuluOrderDetailDTO));
        //todo 验签sign
        WxOrder wxOrder = wxOrderService.getByOutTradeNo(wxFuluOrderDetailDTO.getCustomer_order_no());
        String orderDataJson = wxOrder.getOrderDataJson();
        FuluWxOrderJsonData fuluWxOrderJsonData = JSONObject.parseObject(orderDataJson, FuluWxOrderJsonData.class);
        WxFuluOrderDetailDTO dbWxFuluOrderDetailDTO= fuluWxOrderJsonData.getWxFuluOrderDetailDTO();
        if (wxFuluOrderDetailDTO.getCharge_finish_time()!=null){
            dbWxFuluOrderDetailDTO.setCharge_finish_time(wxFuluOrderDetailDTO.getCharge_finish_time());
        }
        if (wxFuluOrderDetailDTO.getRecharge_description()!=null){
            dbWxFuluOrderDetailDTO.setRecharge_description(wxFuluOrderDetailDTO.getRecharge_description());
        }
        dbWxFuluOrderDetailDTO.setOrder_status(wxFuluOrderDetailDTO.getOrder_status());
        //如果订单失败，则调用微信退款
        if ("failed".equals(wxFuluOrderDetailDTO.getOrder_status())){
            String refundCode = getOrderCode(null);
            wxOrder.setOutRefundNo(refundCode);
            wxOrder.setOrderStatus(OrderStatusEnum.FAILD.getCode());
            threadPoolTaskExecutor.execute(new Runnable() {
                @Override
                public void run() {
                    try {
                        refundRecordService.refund(wxOrder,refundCode,"商品购买失败");
                    } catch (Exception e) {
                        throw new CustomException("订单:"+wxOrder.getOutTradeNo()+"退款失败");
                    }
                }
            });
        }

        //如果订单成功，则调用小程序推送
        if ("success".equals(wxFuluOrderDetailDTO.getOrder_status())){
            wxOrder.setOrderStatus(OrderStatusEnum.SUCCESS.getCode());
            threadPoolTaskExecutor.execute(new Runnable() {
                @Override
                public void run() {
                    try {
                        sendXcxMessage(wxOrder);
                    } catch (Exception e) {
                        e.printStackTrace();
                        throw new CustomException("订单:"+wxOrder.getOutTradeNo()+"推送消息失败");
                    }
                }
            });
        }



        fuluWxOrderJsonData.setWxFuluOrderDetailDTO(dbWxFuluOrderDetailDTO);
        wxOrder.setOrderDataJson(JSONObject.toJSONString(fuluWxOrderJsonData));
        wxOrderService.updateById(wxOrder);

        FilmNotifyReturnDTO filmNotifyReturnDTO = new FilmNotifyReturnDTO();
        filmNotifyReturnDTO.setCode("200");
        filmNotifyReturnDTO.setMessage("请求成功");
        filmNotifyReturnDTO.setSuccess(true);
        return filmNotifyReturnDTO;
    }

    private void sendXcxMessage(WxOrder wxOrder) {
        String xcxMessageToken = wxXcxMessageService.getXcxMessageToken();
        WxSend wxSend = new WxSend();
        String openid = wxOrder.getOpenid();
        wxSend.setTouser(openid);
        wxSend.setTemplate_id("Q4-tQrDwtzFUSLt_PR2kuTxBJ3d62V4Yp2iwx4PAcIE");
        wxSend.setPage("/pages/fulu/orderdes?outTradeNo="+wxOrder.getOutTradeNo());

        JSONObject jsonObject = new JSONObject();
        JSONObject jsonObject1 = new JSONObject();
        JSONObject jsonObject2 = new JSONObject();
        JSONObject jsonObject3 = new JSONObject();
        JSONObject jsonObject4 = new JSONObject();
        JSONObject jsonObject5 = new JSONObject();

        jsonObject1.put("value",wxOrder.getOutTradeNo());
        jsonObject2.put("value","￥"+wxOrder.getTotal()/100.0);
        jsonObject3.put("value",new SimpleDateFormat("yyyy年MM月dd日 HH:mm").format(new Date()));
        jsonObject4.put("value","视频会员");
        jsonObject5.put("value","点击查看详情");

        jsonObject.put("character_string1",jsonObject1);
        jsonObject.put("amount3",jsonObject2);
        jsonObject.put("date4",jsonObject3);
        jsonObject.put("thing6",jsonObject4);
        jsonObject.put("thing5",jsonObject5);


        wxSend.setData(jsonObject);

        wxSend.setLang("zh_CN");
        String result = wxSendService.sendMessage(xcxMessageToken,wxSend);
        log.info("小程序推送请求数据返回值，订单号"+result);
    }



    @Data
    public class FilmNotifyReturnDTO {
        String code;
        String message;
        Boolean success;
    }

}
