package com.miaxis.pc.controller.car;

import com.miaxis.car.domain.UsedCarInfo;
import com.miaxis.car.dto.ExamineUsedCarDto;
import com.miaxis.car.dto.UsedCarInfoDto;
import com.miaxis.car.service.IUsedCarInfoService;
import com.miaxis.common.annotation.Log;
import com.miaxis.common.core.controller.BaseController;
import com.miaxis.common.core.domain.Response;
import com.miaxis.common.core.page.ResponsePageInfo;
import com.miaxis.common.enums.BusinessTypeEnum;
import io.swagger.annotations.*;
import lombok.AllArgsConstructor;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import java.util.Arrays;
import java.util.List;

/**
 * 二手车 controller
 * @author wwl
 * @version 1.0
 * @date 2021/5/26 13:45
 */
@RestController
@AllArgsConstructor
@RequestMapping("/pc/usedCar")
@Api(tags={"【pc-二手车】"})
public class UsedCarInfoController extends BaseController {

    private final IUsedCarInfoService usedCarInfoService;

    /**
     * 查询二手车列表
     */
    @PreAuthorize("@ss.hasPermi('usedCar:usedCar:list')")
    @GetMapping("/list")
    @ApiOperation("查询二手车列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum",value = "当前页码" ,dataType = "int", paramType = "query", required = false),
            @ApiImplicitParam(name = "pageSize",value = "每页数据量" , dataType = "int", paramType = "query", required = false),
    })
    public ResponsePageInfo<UsedCarInfo> list(@ModelAttribute UsedCarInfo usedCarInfo){
        startPage();
        List<UsedCarInfo> list = usedCarInfoService.selectUsedCarInfoList(usedCarInfo);
        return toResponsePageInfo(list);
    }


    /**
     * 获取二手车详细信息
     */
    @PreAuthorize("@ss.hasPermi('usedCar:usedCar:query')")
    @GetMapping(value = "/{id}")
    @ApiOperation("获取二手车详细信息")
    public Response getInfo(
            @ApiParam(name = "id", value = "首页数据id", required = true)
            @PathVariable("id") Long id
    ){
        return usedCarInfoService.getUsedCarById(id);
    }


    /**
     * 修改二手车
     */
    @PreAuthorize("@ss.hasPermi('usedCar:usedCar:edit')")
    @Log(title = "二手车", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping
    @ApiOperation("修改二手车")
    public Response edit(@RequestBody UsedCarInfoDto usedCarInfoDto){
        return usedCarInfoService.updateUsedCarById(usedCarInfoDto);
    }


    /**
     * 二手车审核
     */
    @Log(title = "二手车审核", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping("/usedCarExamine")
    @ApiOperation("二手车审核")
    public Response usedCarExamine(ExamineUsedCarDto examineUsedCarDto){
        return usedCarInfoService.usedCarExamine(examineUsedCarDto);
    }


    /**
     * 删除二手车(伪删除)
     */
    @PreAuthorize("@ss.hasPermi('usedCar:usedCar:remove')")
    @Log(title = "删除二手车", businessType = BusinessTypeEnum.UPDATE)
    @PutMapping("/{ids}")
    @ApiOperation("删除二手车")
    public  Response remove(
            @ApiParam(name = "ids", value = "二手车ids参数", required = true)
            @PathVariable Long[] ids
    ){
        return usedCarInfoService.removeUsedCarByIds(ids);
    }



}
